==> houses_and_lockersV2.1.tar.gz: houses/house_stats.c <==

 /* House_stats.c       Metaprat       6th April 1992  */


inherit "/players/metaprat/houses/house_toolkit_obj";

#include "house_defines.h"


/* standard functions */


id(str) {
   return (str == "house statistics") ||
          (str == "house stats")      ||
          (str == "stats");
}


short() {
   return "house statistics";
}


long(str) {
   write("This is a house statistics object.\n");
   write("The following commands are available:\n");
   write("room_stats   \t- displays stats of the current (house) room.\n");
   write("agent_stats  \t- displays house revenue since last reboot.\n");
   write("master_stats \t- displays all active houses, and all owners.\n");
}



init() {
   if (IAMWIZ && (environment() == this_player())) {
      add_action("room_stats",   "room_stats");
      add_action("agent_stats",  "agent_stats");
      add_action("master_stats", "master_stats");
   }
}


room_stats(str) {
   int    indx;
   int    counter;
   string poss_exits;
   int    tmp_exit_status;

   if (!environment(this_player())->confirm_house()) {
      write("You are not in a house room.\n");
      return 1;
   }
   main_hall       = environment(this_player())->query_main_hall();
   this_room_index = environment(this_player())->query_room_index();
   indx = this_room_index;
   write("File name: \t" + file_name(environment(this_player())) + ".\n");
   write("Main hall: \t" + file_name(main_hall)     + ".\n");
   write("Room index:\t" + this_room_index          + ".\n");
   if (indx) {
      write("Note: ALL other room variables are stored within the\n");
      write("main hall object, and queried when required.\n");
      write("A summary of the main_hall info for this room follows:\n");
   }
   else {
      write("Note: This is the main_hall object, where all the information\n");
      write("for the entire house is stored.  A summary of the data for\n");
      write("this room follows.\n");
   }
   write("Owner:     \t" + capitalize(GETOWNER) + ".\n");
   write("Short:     \t" + main_hall->get_rooms_short(indx) + ".\n");
   write("Long:      \t"+strlen(main_hall->get_rooms_long(indx))+" bytes.\n");
   poss_exits = main_hall->query_room_position(indx);
   write("Position:  \tX = " + poss_exits[0] +
                    ", Y = " + poss_exits[1] +
                    ", Z = " + poss_exits[2] + ".\n");
   poss_exits = main_hall->get_rooms_furnishings(indx);
   if (!poss_exits || !pointerp(poss_exits) || !sizeof(poss_exits)) {
       write("Furnish:   \tNo furnish items in the room.\n");
   }
   else {
       write("Furnish:   \t" + implode(poss_exits, ", ") + " set.\n");
   }
   poss_exits = main_hall->get_rooms_items(indx);
   if (!poss_exits || !pointerp(poss_exits)  || !sizeof(poss_exits)) {
       write("Items:     \tNo examinable items in the room.\n");
   }
   else {
       write("Items:     \t");
       write(poss_exits[counter]);
       for (counter = 2; counter < sizeof(poss_exits) - 1; counter += 2) {
          write(", " + poss_exits[counter]);
       }
       write(".\n");
   }
   write("Exits:\n");
   poss_exits = main_hall->get_valid_directions();
   for (counter = 0; counter < sizeof(poss_exits); counter ++) {
      tmp_exit_status = main_hall->get_exit_status(indx,poss_exits[counter]);
      if (tmp_exit_status != DOOR_NONE) {
         write(poss_exits[counter] + " has status:\t" + tmp_exit_status);
         if (tmp_exit_status != DOOR_ONEWAY) {
            write(", leading to room:\t" +
                  main_hall->direction_room(indx, poss_exits[counter])+".\n");
         }
         else {
            write(", leading outside to:\t" +
                  main_hall->file_name_exit(indx, poss_exits[counter])+".\n");
         }
      }
   }
   return 1;
}


agent_stats() {
   MONEY->show_revenue();
   return 1;
}


master_stats() {
   write("Currently active houses :\n");
   MASTERHOUSE->master_stats();
   return 1;
}

==> houses_and_lockersV2.2.tar.gz: houses/house_stats.c <==

 /* House_stats.c       Metaprat       6th April 1992  */


inherit "/players/metaprat/houses/house_toolkit_obj";

#include "house_defines.h"


/* standard functions */


id(str) {
   return (str == "house statistics") ||
          (str == "house stats")      ||
          (str == "stats");
}


short() {
   return "house statistics";
}


long(str) {
   write("This is a house statistics object.\n");
   write("The following commands are available:\n");
   write("room_stats        \t- shows stats of the current (house) room.\n");
   write("agent_stats       \t- shows house revenue since last reboot.\n");
   write("master_stats      \t- shows the following information in one go:\n");
   write("show_active_houses\t- shows all the currently cloned houses.\n");
   write("show_house_owners \t- shows all house owners.\n");
   write("show_public_houses\t- shows all houses with 'public' set.\n");
   write("show_revenue      \t- shows outstanding revenue due to owners.\n");
   write("voting_stats      \t- shows current votes etc of voting booth.\n");
}



init() {
   if (IAMWIZ && (environment() == this_player())) {
      add_action("room_stats",         "room_stats");
      add_action("agent_stats",        "agent_stats");
      add_action("master_stats",       "master_stats");
      add_action("show_active_houses", "show_active_houses");
      add_action("show_house_owners",  "show_house_owners");
      add_action("show_public_houses", "show_public_houses");
      add_action("show_revenue",       "show_revenue");
      add_action("voting_stats",       "voting_stats");
   }
}


room_stats(str) {
   int    indx;
   int    counter;
   string poss_exits;
   int    tmp_exit_status;

   if (!environment(this_player())->confirm_house()) {
      write("You are not in a house room.\n");
      return 1;
   }
   main_hall       = environment(this_player())->query_main_hall();
   this_room_index = environment(this_player())->query_room_index();
   indx = this_room_index;
   write("File name: \t" + file_name(environment(this_player())) + ".\n");
   write("Main hall: \t" + file_name(main_hall)     + ".\n");
   write("Room index:\t" + this_room_index          + ".\n");
   if (indx) {
      write("Note: ALL other room variables are stored within the\n");
      write("main hall object, and queried when required.\n");
      write("A summary of the main_hall info for this room follows:\n");
   }
   else {
      write("Note: This is the main_hall object, where all the information\n");
      write("for the entire house is stored.  A summary of the data for\n");
      write("this room follows.\n");
   }
   write("Owner:     \t" + capitalize(GETOWNER) + ".\n");
   write("Short:     \t" + main_hall->get_rooms_short(indx) + ".\n");
   write("Long:      \t"+strlen(main_hall->get_rooms_long(indx))+" bytes.\n");
   poss_exits = main_hall->query_room_position(indx);
   write("Position:  \tX = " + poss_exits[0] +
                    ", Y = " + poss_exits[1] +
                    ", Z = " + poss_exits[2] + ".\n");
   poss_exits = main_hall->get_rooms_furnishings(indx);
   if (!poss_exits || !pointerp(poss_exits) || !sizeof(poss_exits)) {
       write("Furnish:   \tNo furnish items in the room.\n");
   }
   else {
       write("Furnish:   \t" + implode(poss_exits, ", ") + " set.\n");
   }
   poss_exits = main_hall->get_rooms_items(indx);
   if (!poss_exits || !pointerp(poss_exits)  || !sizeof(poss_exits)) {
       write("Items:     \tNo examinable items in the room.\n");
   }
   else {
       write("Items:     \t");
       write(poss_exits[counter]);
       for (counter = 2; counter < sizeof(poss_exits) - 1; counter += 2) {
          write(", " + poss_exits[counter]);
       }
       write(".\n");
   }
   write("Exits:\n");
   poss_exits = main_hall->get_valid_directions();
   for (counter = 0; counter < sizeof(poss_exits); counter ++) {
      tmp_exit_status = main_hall->get_exit_status(indx,poss_exits[counter]);
      if (tmp_exit_status != DOOR_NONE) {
         write(poss_exits[counter] + " has status:\t" + tmp_exit_status);
         if (tmp_exit_status != DOOR_ONEWAY) {
            write(", leading to room:\t" +
                  main_hall->direction_room(indx, poss_exits[counter])+".\n");
         }
         else {
            write(", leading outside to:\t" +
                  main_hall->file_name_exit(indx, poss_exits[counter])+".\n");
         }
      }
   }
   return 1;
}



agent_stats()        { MONEY->show_revenue();             return 1; }
master_stats()       { MASTERHOUSE->master_stats();       return 1; }
show_active_houses() { MASTERHOUSE->show_active_houses(); return 1; }
show_house_owners()  { MASTERHOUSE->show_house_owners();  return 1; }
show_public_houses() { MASTERHOUSE->show_public_houses(); return 1; }
show_revenue()       { MASTERHOUSE->show_revenue();       return 1; }
voting_stats()       { VOTING->voting_stats();            return 1; }
